==> mozile-0.7.4-devel.zip: testing/index.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license2.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is James A. Overton's code (james@overton.ca).
 *
 * The Initial Developer of the Original Code is James A. Overton.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *	James A. Overton <james@overton.ca>
 *
 * ***** END LICENSE BLOCK ***** */

/** 
 * @fileoverview Some JavaScript code to run the main testing page.
 * @link http://mozile.mozdev.org 
 * @author James A. Overton <james@overton.ca>
 * @version 0.7
 */

function openUnitTestPage(page) {
	//alert(page);
	var jsunit = "../jsunit/testRunner.html";
	var options = "autoRun=true";
	var root = document.URL;
	if(root.indexOf('//')!=-1) {
		root = root.slice(root.indexOf('//')+2, root.length);
	}
	var path = root.slice(0,root.lastIndexOf('/')+1);
	var url = jsunit +"?"+ options +"&testpage="+ path + page;
	//alert(url);
	window.open(url,"Mozile Tests");
}

function openPerformanceTestPage(page) {
	//alert(page);
	var root = document.URL;
	if(root.indexOf('//')!=-1) {
		root = root.slice(root.indexOf('//')+2, root.length);
	}
	var path = root.slice(0,root.lastIndexOf('/')+1);
	var url = path + page;
	//alert(url);
	window.open(url,"Mozile Tests");
}

==> mozile-0.7.5-devel.zip: testing/index.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license2.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is James A. Overton's code (james@overton.ca).
 *
 * The Initial Developer of the Original Code is James A. Overton.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *	James A. Overton <james@overton.ca>
 *
 * ***** END LICENSE BLOCK ***** */

/** 
 * @fileoverview Some JavaScript code to run the main testing page.
 * @link http://mozile.mozdev.org 
 * @author James A. Overton <james@overton.ca>
 * @version 0.7
 */

function openJsUnitTestPage(page) {
	//alert(page);
	var jsunit = "../jsunit/testRunner.html";
	var options = "autoRun=true";
	var root = document.URL;
	if(root.indexOf('//')!=-1) {
		root = root.slice(root.indexOf('//')+2, root.length);
	}
	var path = root.slice(0,root.lastIndexOf('/')+1);
	var url = jsunit +"?"+ options +"&testpage="+ path + page;
	//alert(url);
	window.open(url,"Mozile Tests");
}

function openPerformanceTestPage(page) {
	//alert(page);
	var root = document.URL;
	if(root.indexOf('//')!=-1) {
		root = root.slice(root.indexOf('//')+2, root.length);
	}
	var path = root.slice(0,root.lastIndexOf('/')+1);
	var url = path + page;
	//alert(url);
	window.open(url,"Mozile Tests");
}
